==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/LinksSelfAndFullUsersLifecycle.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import com.okta.sdk.resource.model.HrefObjectActivateLink;
import com.okta.sdk.resource.model.HrefObjectDeactivateLink;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import com.okta.sdk.resource.model.HrefObjectSuspendLink;
import com.okta.sdk.resource.model.HrefObjectUnsuspendLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksSelfAndFullUsersLifecycle
 */
@JsonPropertyOrder({ LinksSelfAndFullUsersLifecycle.JSON_PROPERTY_SELF,
        LinksSelfAndFullUsersLifecycle.JSON_PROPERTY_ACTIVATE, LinksSelfAndFullUsersLifecycle.JSON_PROPERTY_DEACTIVATE,
        LinksSelfAndFullUsersLifecycle.JSON_PROPERTY_SUSPEND, LinksSelfAndFullUsersLifecycle.JSON_PROPERTY_UNSUSPEND,
        LinksSelfAndFullUsersLifecycle.JSON_PROPERTY_USERS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksSelfAndFullUsersLifecycle implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_ACTIVATE = "activate";
    private HrefObjectActivateLink activate;

    public static final String JSON_PROPERTY_DEACTIVATE = "deactivate";
    private HrefObjectDeactivateLink deactivate;

    public static final String JSON_PROPERTY_SUSPEND = "suspend";
    private HrefObjectSuspendLink suspend;

    public static final String JSON_PROPERTY_UNSUSPEND = "unsuspend";
    private HrefObjectUnsuspendLink unsuspend;

    public static final String JSON_PROPERTY_USERS = "users";
    private HrefObject users;

    public LinksSelfAndFullUsersLifecycle() {
    }

    public LinksSelfAndFullUsersLifecycle self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public LinksSelfAndFullUsersLifecycle activate(HrefObjectActivateLink activate) {

        this.activate = activate;
        return this;
    }

    /**
     * Get activate
     *
     * @return activate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectActivateLink getActivate() {
        return activate;
    }

    @JsonProperty(JSON_PROPERTY_ACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setActivate(HrefObjectActivateLink activate) {
        this.activate = activate;
    }

    public LinksSelfAndFullUsersLifecycle deactivate(HrefObjectDeactivateLink deactivate) {

        this.deactivate = deactivate;
        return this;
    }

    /**
     * Get deactivate
     *
     * @return deactivate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectDeactivateLink getDeactivate() {
        return deactivate;
    }

    @JsonProperty(JSON_PROPERTY_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDeactivate(HrefObjectDeactivateLink deactivate) {
        this.deactivate = deactivate;
    }

    public LinksSelfAndFullUsersLifecycle suspend(HrefObjectSuspendLink suspend) {

        this.suspend = suspend;
        return this;
    }

    /**
     * Get suspend
     *
     * @return suspend
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SUSPEND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSuspendLink getSuspend() {
        return suspend;
    }

    @JsonProperty(JSON_PROPERTY_SUSPEND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSuspend(HrefObjectSuspendLink suspend) {
        this.suspend = suspend;
    }

    public LinksSelfAndFullUsersLifecycle unsuspend(HrefObjectUnsuspendLink unsuspend) {

        this.unsuspend = unsuspend;
        return this;
    }

    /**
     * Get unsuspend
     *
     * @return unsuspend
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_UNSUSPEND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectUnsuspendLink getUnsuspend() {
        return unsuspend;
    }

    @JsonProperty(JSON_PROPERTY_UNSUSPEND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUnsuspend(HrefObjectUnsuspendLink unsuspend) {
        this.unsuspend = unsuspend;
    }

    public LinksSelfAndFullUsersLifecycle users(HrefObject users) {

        this.users = users;
        return this;
    }

    /**
     * Link to Device users
     *
     * @return users
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Link to Device users")
    @JsonProperty(JSON_PROPERTY_USERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getUsers() {
        return users;
    }

    @JsonProperty(JSON_PROPERTY_USERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUsers(HrefObject users) {
        this.users = users;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksSelfAndFullUsersLifecycle linksSelfAndFullUsersLifecycle = (LinksSelfAndFullUsersLifecycle) o;
        return Objects.equals(this.self, linksSelfAndFullUsersLifecycle.self)
                && Objects.equals(this.activate, linksSelfAndFullUsersLifecycle.activate)
                && Objects.equals(this.deactivate, linksSelfAndFullUsersLifecycle.deactivate)
                && Objects.equals(this.suspend, linksSelfAndFullUsersLifecycle.suspend)
                && Objects.equals(this.unsuspend, linksSelfAndFullUsersLifecycle.unsuspend)
                && Objects.equals(this.users, linksSelfAndFullUsersLifecycle.users);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, activate, deactivate, suspend, unsuspend, users);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksSelfAndFullUsersLifecycle {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    activate: ").append(toIndentedString(activate)).append("\n");
        sb.append("    deactivate: ").append(toIndentedString(deactivate)).append("\n");
        sb.append("    suspend: ").append(toIndentedString(suspend)).append("\n");
        sb.append("    unsuspend: ").append(toIndentedString(unsuspend)).append("\n");
        sb.append("    users: ").append(toIndentedString(users)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/LinksSelfAndFullUsersLifecycle.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import com.okta.sdk.resource.model.HrefObjectActivateLink;
import com.okta.sdk.resource.model.HrefObjectDeactivateLink;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import com.okta.sdk.resource.model.HrefObjectSuspendLink;
import com.okta.sdk.resource.model.HrefObjectUnsuspendLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksSelfAndFullUsersLifecycle
 */
@JsonPropertyOrder({ LinksSelfAndFullUsersLifecycle.JSON_PROPERTY_SELF,
        LinksSelfAndFullUsersLifecycle.JSON_PROPERTY_ACTIVATE, LinksSelfAndFullUsersLifecycle.JSON_PROPERTY_DEACTIVATE,
        LinksSelfAndFullUsersLifecycle.JSON_PROPERTY_SUSPEND, LinksSelfAndFullUsersLifecycle.JSON_PROPERTY_UNSUSPEND,
        LinksSelfAndFullUsersLifecycle.JSON_PROPERTY_USERS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksSelfAndFullUsersLifecycle implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_ACTIVATE = "activate";
    private HrefObjectActivateLink activate;

    public static final String JSON_PROPERTY_DEACTIVATE = "deactivate";
    private HrefObjectDeactivateLink deactivate;

    public static final String JSON_PROPERTY_SUSPEND = "suspend";
    private HrefObjectSuspendLink suspend;

    public static final String JSON_PROPERTY_UNSUSPEND = "unsuspend";
    private HrefObjectUnsuspendLink unsuspend;

    public static final String JSON_PROPERTY_USERS = "users";
    private HrefObject users;

    public LinksSelfAndFullUsersLifecycle() {
    }

    public LinksSelfAndFullUsersLifecycle self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public LinksSelfAndFullUsersLifecycle activate(HrefObjectActivateLink activate) {

        this.activate = activate;
        return this;
    }

    /**
     * Get activate
     *
     * @return activate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectActivateLink getActivate() {
        return activate;
    }

    @JsonProperty(JSON_PROPERTY_ACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setActivate(HrefObjectActivateLink activate) {
        this.activate = activate;
    }

    public LinksSelfAndFullUsersLifecycle deactivate(HrefObjectDeactivateLink deactivate) {

        this.deactivate = deactivate;
        return this;
    }

    /**
     * Get deactivate
     *
     * @return deactivate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectDeactivateLink getDeactivate() {
        return deactivate;
    }

    @JsonProperty(JSON_PROPERTY_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDeactivate(HrefObjectDeactivateLink deactivate) {
        this.deactivate = deactivate;
    }

    public LinksSelfAndFullUsersLifecycle suspend(HrefObjectSuspendLink suspend) {

        this.suspend = suspend;
        return this;
    }

    /**
     * Get suspend
     *
     * @return suspend
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SUSPEND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSuspendLink getSuspend() {
        return suspend;
    }

    @JsonProperty(JSON_PROPERTY_SUSPEND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSuspend(HrefObjectSuspendLink suspend) {
        this.suspend = suspend;
    }

    public LinksSelfAndFullUsersLifecycle unsuspend(HrefObjectUnsuspendLink unsuspend) {

        this.unsuspend = unsuspend;
        return this;
    }

    /**
     * Get unsuspend
     *
     * @return unsuspend
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_UNSUSPEND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectUnsuspendLink getUnsuspend() {
        return unsuspend;
    }

    @JsonProperty(JSON_PROPERTY_UNSUSPEND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUnsuspend(HrefObjectUnsuspendLink unsuspend) {
        this.unsuspend = unsuspend;
    }

    public LinksSelfAndFullUsersLifecycle users(HrefObject users) {

        this.users = users;
        return this;
    }

    /**
     * Link to Device users
     *
     * @return users
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Link to Device users")
    @JsonProperty(JSON_PROPERTY_USERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getUsers() {
        return users;
    }

    @JsonProperty(JSON_PROPERTY_USERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUsers(HrefObject users) {
        this.users = users;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksSelfAndFullUsersLifecycle linksSelfAndFullUsersLifecycle = (LinksSelfAndFullUsersLifecycle) o;
        return Objects.equals(this.self, linksSelfAndFullUsersLifecycle.self)
                && Objects.equals(this.activate, linksSelfAndFullUsersLifecycle.activate)
                && Objects.equals(this.deactivate, linksSelfAndFullUsersLifecycle.deactivate)
                && Objects.equals(this.suspend, linksSelfAndFullUsersLifecycle.suspend)
                && Objects.equals(this.unsuspend, linksSelfAndFullUsersLifecycle.unsuspend)
                && Objects.equals(this.users, linksSelfAndFullUsersLifecycle.users);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, activate, deactivate, suspend, unsuspend, users);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksSelfAndFullUsersLifecycle {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    activate: ").append(toIndentedString(activate)).append("\n");
        sb.append("    deactivate: ").append(toIndentedString(deactivate)).append("\n");
        sb.append("    suspend: ").append(toIndentedString(suspend)).append("\n");
        sb.append("    unsuspend: ").append(toIndentedString(unsuspend)).append("\n");
        sb.append("    users: ").append(toIndentedString(users)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
